/** Safely parses an integer.
 *
 *  If the input is not a number or parseable number, it returns `null`.
 *  If the number is not safely parsed (i.e., is `NaN` or `Infinity`),
 *  it returns `null`.
 *  In the event of a decimal number, such as `1.5`, it returns `null`.
 */
export declare function safeParseInt(x: unknown): number | null;
/** Safely parses a float.
 *
 *  If the input is not a number or parseable number, it returns `null`.
 *  If the number is not safely parsed (i.e., is `NaN` or `Infinity`),
 *  it returns `null`.
 */
export declare function safeParseFloat(x: unknown): number | null;
/** Tries to convert a value into a string. Unlike `JSON.stringify`, this attempts
 *  to convert the value into a string in something an end-user could read.
 *  For example, it converts `Error` objects into their message and `Date` objects
 *  into a local time string, among other things.
 *
 *  If a `fallback` function is provided, it will be called when the value is not
 *  stringifiable by this function. The fallback function should return a string.
 */
export declare function tryString(thing: unknown, fallback?: (thing: object) => string): string;
